#!/usr/bin/perl 

# Copyright - Rolf Poser - rolf [at] stasolutions [dot] co /dot/ za
# 01 December 2003 under the GPL license agreement!
#
# Version 0.1 - Initial release.

# CREDITS:
#
# The idea is based on the original script by <rs at rhapsodyk dot net> and/or
# Brian Stanback (depending on where you look on the cacti site). 
# I have modified it to an extreme extent, and the original can hardly
# be recognised in this release!!

# OVERVIEW:
#
# This script doesn't look at requests/sec since that is a statistic
# Apache averages over the uptime of the httpd process!!
#
# It uses the simplified form of the status page so that the units of measure
# are always the same for total kbytes served.
#
# We also pull out basic busy / idle information. All 4 fields are shown
# on stdout by default.
#
# You can optionally specify a hostname/ip address as a parameter, otherwise
# "localhost" will be assumed. (e.g. perl $path/unix_apachestats.pl hostname)


# INSTALLATION:
#
# This script lives in $cacti_path/scripts, and then you will need to be
# sure that the below config is set up correctly in your httpd.conf (you will
# need to add support for mod_status). 
#
# You may need to define additional ACLs for the "Allow from" statement 
# to allow querying from a remote server. 
#
# ExtendedStatus        on 
# <Location /server-status> 
#     SetHandler server-status 
#     Order deny,allow 
#     Deny from all 
#     Allow from localhost 
# </Location> 
#
#
# You may also want to check that "lynx" is in the path as specified below.

#
# CACTI CONFIGURATION:
#
# I have included 4 xml template exports - one for the data source and 
# template that specifies how to get hold of the data, and the other three
# deal with the graph templates for hits, kbytes and threads respectively.
#
# You will need to import these - YOU NEED TO START WITH THE DATA template
# and then add the others, since they depend on the data template.
#
# Now modify the host template you wish to use - I modified my "Local Linux
# Machine" to include the 3 graph templates.
#
#
# MISCELLANEOUS:
#
# Have fun!! I don't promise to be able to support you if you have questions,
# but you are welcome to give me a holler if you get stuck.
#

my $hostname = $ARGV[0];

chomp $hostname;

if ($hostname eq '') {
        $hostname = "localhost";
}

$URL = "http:\/\/".$hostname."\/server-status?auto";

$output = `/bin/bash -c '/usr/bin/lynx -dump $URL'`; 

$output =~ /Total Accesses: (.*)/; 
print "total_accesses:".$1." "; 
$output =~ /Total kBytes: (.*)/; 
print "total_kbytes:".$1." ";
$output =~ /BusyWorkers: (.*)/;
print "busy_workers:".$1." ";
$output =~ /IdleWorkers: (.*)/;
print "idle_workers:".$1;
